==> gurux_dlms-1.0.12-py3-none-any.whl: gurux_dlms/objects/enums/CreditType.py <==
#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
from enum import Enum
class CreditType(Enum):
    """Enumerates credit types.
    Online help:
    http://www.gurux.fi/Gurux.DLMS.Objects.GXDLMSCredit
    """
    #pylint: disable=too-few-public-methods

    #
    # Token credit.
    #
    TOKEN = 0
    #
    # Reserved credit.
    #
    RESERVED = 1
    #
    # Emergency credit.
    #
    EMERGENCY = 2
    #
    # TimeBased credit.
    #
    TIME_BASED = 3
    #
    # Consumption based credit.
    #
    CONSUMPTION_BASED = 4

==> gurux_dlms-1.0.31-py3-none-any.whl: gurux_dlms/objects/enums/CreditType.py <==
#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
#pylint: disable=broad-except,no-name-in-module
try:
    from enum import IntEnum
    __base = IntEnum
except Exception:
    __base = object

class CreditType(__base):
    """Enumerates credit types.
    Online help:
    http://www.gurux.fi/Gurux.DLMS.Objects.GXDLMSCredit
    """
    #pylint: disable=too-few-public-methods

    #
    # Token credit.
    #
    TOKEN = 0
    #
    # Reserved credit.
    #
    RESERVED = 1
    #
    # Emergency credit.
    #
    EMERGENCY = 2
    #
    # TimeBased credit.
    #
    TIME_BASED = 3
    #
    # Consumption based credit.
    #
    CONSUMPTION_BASED = 4
